# README

This directory contains scripts for running PsyNet commands through Docker.
We are currently considering removing this route to focus on the standard
virtual environment route. For the latest guidance,
please visit the [PsyNet website](https://psynet.dev).
